@@ -1,6 +1,6 @@
 """Utility functions for common tasks when composing functions."""
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 __all__ = (
     "compose",
     "pipe",
@@ -12,8 +12,13 @@ __all__ = (
     "mask",
     "flat",
     "unique",
+    "attr",
+    "item",
 )
 
+from operator import attrgetter as attr
+from operator import itemgetter as item
+
 
 def compose(*fns):
     """Compose functions. `compose(f, g, h)(x)` is equivalent to `f(g(h(x)))`"""
